SecretKey

Struct SecretKey 

pub struct SecretKey<'a> { /* private fields */ }
A symmetric secret key used with the BLAKE3, HS256, HS384, and HS512 algorithms.

The key is borrowed, so it must outlive any signing or verification.

Signing and verification fail with Error::InvalidKey if algorithm is not one of the supported MAC algorithms, if a BLAKE3 key is not exactly 32 bytes long, or if an HMAC key is shorter than 16 bytes (128 bits).

Implementations

Source

impl<'a> SecretKey<'a>

pub fn new(algorithm: Algorithm, key: &'a [u8]) -> Self

Creates a new SecretKey for algorithm.