VerifyOptions

Struct VerifyOptions 

pub struct VerifyOptions<'a> {
    pub allowed_time_drift: Duration,
    pub nbf: bool,
    pub exp: bool,
    pub aud: Option<&'a [&'a str]>,
    pub iss: Option<&'a [&'a str]>,
    pub clock: Option<&'a dyn Clock>,
}

Fields

allowed_time_drift: Duration

Allowed time drift for nbf and exp verification in order to account for devices with inacurate clocks. default: 30 seconds

nbf: bool

default: true

exp: bool

default: true

aud: Option<&'a [&'a str]>

default: None

iss: Option<&'a [&'a str]>

default: None

clock: Option<&'a dyn Clock>

default: Some(&SYSTEM_CLOCK)